@@ -105,7 +105,7 @@ def run_blind_test(
 
     print(f"=== {category} BLIND TEST STARTING ===")
     with open(path, "r") as f:
-        df = pd.read_csv(f, encoding="utf-8")
+        df = pd.read_csv(f, encoding="latin1")
         for i in trange(len(df)):
 
             # Get original text and predicted intent
